aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSkye Deving <76892045+skyedeving@users.noreply.github.com>2021-01-11 02:27:10 -0600
committerSkye Deving <76892045+skyedeving@users.noreply.github.com>2021-01-11 02:27:10 -0600
commit90bd02a3e9cf55d292dba4f59230f210bffa224f (patch)
tree624475d14306a0eb1e4adf7d626b21c501997eca
parent812d04d969afd59c87295ddb23e67b758253b313 (diff)
Set music and objection to volume slider in update_character
-rw-r--r--src/courtroom.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/courtroom.cpp b/src/courtroom.cpp
index 0f807c33..3bbf82a4 100644
--- a/src/courtroom.cpp
+++ b/src/courtroom.cpp
@@ -1380,7 +1380,9 @@ void Courtroom::update_character(int p_cid)
ui_char_select_background->hide();
ui_ic_chat_message->setEnabled(m_cid != -1);
ui_ic_chat_message->setFocus();
- // have to call these to make sure sfx and blips don't get accidentally muted forever when we change characters
+ // have to call these to make sure music, sfx, and blips don't get accidentally muted forever when we change characters
+ music_player->set_volume(ui_music_slider->value(), 0);
+ objection_player->set_volume(ui_sfx_slider->value());
sfx_player->set_volume(ui_sfx_slider->value());
blip_player->set_volume(ui_blip_slider->value());
}